You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ambari.apache.org by al...@apache.org on 2015/03/20 00:41:25 UTC

[3/6] ambari git commit: AMBARI-10134. Install Wizard: Install, Start and Test page shows Views icon in top nav, but it is not functional (clicking does nothing) (alexantonenko)

AMBARI-10134. Install Wizard: Install, Start and Test page shows Views icon in top nav, but it is not functional (clicking does nothing) (alexantonenko)


Project: http://git-wip-us.apache.org/repos/asf/ambari/repo
Commit: http://git-wip-us.apache.org/repos/asf/ambari/commit/0fe14ef0
Tree: http://git-wip-us.apache.org/repos/asf/ambari/tree/0fe14ef0
Diff: http://git-wip-us.apache.org/repos/asf/ambari/diff/0fe14ef0

Branch: refs/heads/trunk
Commit: 0fe14ef0c64d5a28780668dd070a82a5173e412f
Parents: faae1cb
Author: Alex Antonenko <hi...@gmail.com>
Authored: Thu Mar 19 22:29:22 2015 +0200
Committer: Alex Antonenko <hi...@gmail.com>
Committed: Fri Mar 20 01:40:59 2015 +0200

----------------------------------------------------------------------
 ambari-web/app/routes/installer.js | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ambari/blob/0fe14ef0/ambari-web/app/routes/installer.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/routes/installer.js b/ambari-web/app/routes/installer.js
index a88ae29..04b2dc0 100644
--- a/ambari-web/app/routes/installer.js
+++ b/ambari-web/app/routes/installer.js
@@ -381,8 +381,9 @@ module.exports = Em.Route.extend(App.RouterRedirections, {
       }
     },
     unroutePath: function (router, context) {
-      // exclusion for transition to Admin View
-      if (context === '/adminView') {
+      // exclusion for transition to Admin view or Views view
+      if (context === '/adminView' ||
+          context === '/main/views.index') {
         this._super(router, context);
       } else {
         return false;